.. include:: intro.rst

Contents
=========

.. toctree::
    :maxdepth: 2

    pyplates
    advanced
    apiref
    developing



.. toctree::
    :hidden:

    intro
    why_yaml

Thanks
======

MetaMetrics, Inc
----------------

The original development of this library was to streamline the deployment
process at MetaMetrics. We've been using pyplates for a while now, and we
always intended to get it out for others to use once we were able to make
the time. Normally, that means that it would never get done.

MetaMetrics deserves special thanks for not just allowing this to be shared,
but actively encouraging its publishing. If that sounds like a good place to
work, that's because it *is* a good place to work.

http://www.metametricsinc.com/job-openings/

Contributors
------------

..
    Don't forget to add yourself if you contribute to pyplates!

Sean Myers <sean.dst@gmail.com>
    Main contributor, project "owner"

Jon Woodbury <jpwoodbu@mybox.org>
    Did a lot of practical work with pyplates; all of the examples in these
    docs are based on his early work with pyplates

GitHub Contributors
    https://github.com/seandst/cfn-pyplates/graphs/contributors
